@@ -5,18 +5,20 @@ package Pod::Simple::Wiki::Twiki;
 # Pod::Simple::Wiki::Twiki - A class for creating Pod to Twiki filters.
 #
 #
-# Copyright 2003-2008, John McNamara, jmcnamara@cpan.org
+# Copyright 2003-2012, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
 
+# perltidy with the following options: -mbl=2 -pt=0 -nola
+
 use Pod::Simple::Wiki;
 use strict;
 use vars qw(@ISA $VERSION);
 
 
 @ISA     = qw(Pod::Simple::Wiki);
-$VERSION = '0.08';
+$VERSION = '0.15';
 
 
 ###############################################################################
@@ -24,24 +26,24 @@ $VERSION = '0.08';
 # The tag to wiki mappings.
 #
 my $tags = {
-            '<b>'    => '*',
-            '</b>'   => '*',
-            '<i>'    => '_',
-            '</i>'   => '_',
-            '<tt>'   => '=',
-            '</tt>'  => '=',
-            '<pre>'  => "\n<verbatim>\n",
-            '</pre>' => "\n</verbatim>\n\n",
+    '<b>'    => '*',
+    '</b>'   => '*',
+    '<i>'    => '_',
+    '</i>'   => '_',
+    '<tt>'   => '=',
+    '</tt>'  => '=',
+    '<pre>'  => "\n<verbatim>\n",
+    '</pre>' => "\n</verbatim>\n\n",
 
-            '<h1>'   => '---+ ',
-            '</h1>'  => "\n\n",
-            '<h2>'   => '---++ ',
-            '</h2>'  => "\n\n",
-            '<h3>'   => '---+++ ',
-            '</h3>'  => "\n\n",
-            '<h4>'   => '---++++ ',
-            '</h4>'  => "\n\n",
-           };
+    '<h1>'  => '---+ ',
+    '</h1>' => "\n\n",
+    '<h2>'  => '---++ ',
+    '</h2>' => "\n\n",
+    '<h3>'  => '---+++ ',
+    '</h3>' => "\n\n",
+    '<h4>'  => '---++++ ',
+    '</h4>' => "\n\n",
+};
 
 
 ###############################################################################
@@ -52,11 +54,11 @@ my $tags = {
 #
 sub new {
 
-    my $class                   = shift;
-    my $self                    = Pod::Simple::Wiki->new('wiki', @_);
-       $self->{_tags}           = $tags;
+    my $class = shift;
+    my $self = Pod::Simple::Wiki->new( 'wiki', @_ );
+    $self->{_tags} = $tags;
 
-    bless  $self, $class;
+    bless $self, $class;
     return $self;
 }
 
@@ -74,14 +76,14 @@ sub _indent_item {
     my $item_param   = $_[1];
     my $indent_level = $self->{_item_indent};
 
-    if    ($item_type eq 'bullet') {
-         $self->_append('   ' x $indent_level . '* ');
+    if ( $item_type eq 'bullet' ) {
+        $self->_append( '   ' x $indent_level . '* ' );
     }
-    elsif ($item_type eq 'number') {
-         $self->_append('   ' x $indent_level . $item_param . '. ');
+    elsif ( $item_type eq 'number' ) {
+        $self->_append( '   ' x $indent_level . $item_param . '. ' );
     }
-    elsif ($item_type eq 'text') {
-         $self->_append('   ' x $indent_level . '$ ' );
+    elsif ( $item_type eq 'text' ) {
+        $self->_append( '   ' x $indent_level . '$ ' );
     }
 }
 
@@ -117,7 +119,7 @@ sub _handle_text {
 # Text     lists
 # Block    lists
 #
-sub _end_item_text     {$_[0]->_output(': ')}
+sub _end_item_text { $_[0]->_output( ': ' ) }
 
 
 ###############################################################################
@@ -131,7 +133,8 @@ sub _start_Para {
     my $self         = shift;
     my $indent_level = $self->{_item_indent};
 
-    if ($self->{_in_over_block}) {
+    if ( $self->{_in_over_block} ) {
+
         # Do something here is necessary
     }
 }
@@ -173,7 +176,7 @@ The C<Pod::Simple::Wiki::Twiki> module is used for converting Pod text to Wiki t
 
 Pod (Plain Old Documentation) is a simple markup language used for writing Perl documentation.
 
-For an introduction to Twiki see: http://twiki.org
+For an introduction to Twiki see: L<http://twiki.org>
 
 This module isn't generally invoked directly. Instead it is called via C<Pod::Simple::Wiki>. See the L<Pod::Simple::Wiki> and L<pod2wiki> documentation for more information.
 
@@ -205,6 +208,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MMIII-MMVIII, John McNamara.
+MMIII-MMXII, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
